@@ -17,13 +17,10 @@ def bot_guilds():
 def common_guilds(user: list, bot:list, permissions = 0x20):
     return [guild for guild in user if guild['id'] in map(lambda i: i['id'], bot) and (guild['permissions'] & permissions) == permissions]
 
-def permissions(user_token, guild_id, permissions = 0x20):
-    guild_user = requests.get("https://discord.com/api/v6/users/@me/guilds", headers={"Authorization": f"Bearer {user_token}"})
-    guild_user.raise_for_status()
-    for serwer in guild_user:
-        x = x+1
-        if serwer['id'] == guild_id:            
+def permissions(user_guilds, guild_id, permissions = 0x20):
+    for server in guild_user:
+        if int(server['id']) == int(guild_id):
             if (int(serwer['permissions_new']) & int(permissions)) == permissions:
                 return True
             else:
-                return False
\ No newline at end of file
+                return False
